@@ -50,11 +50,11 @@ END
 
    EXPORT => 'Export as...',
 
-   IMAGE_LINK => '...low-res image',
+   IMAGE_LINK => '...low-res PNG image',
 
-   SVG_LINK   => '...high-res image',
+   SVG_LINK   => '...editable SVG image',
 
-   PDF_LINK   => '...PDF',
+   PDF_LINK   => '...high-res PDF',
    
    DUMP_GFF   => '...GFF annotation table',
 
