@@ -1,6 +1,6 @@
 package Bio::Graphics::Browser2::UserTracks;
 
-# $Id: UserTracks.pm 23270 2010-05-25 01:48:42Z lstein $
+# $Id: UserTracks.pm 23485 2010-06-28 20:11:22Z lstein $
 use strict;
 use Bio::Graphics::Browser2::DataSource;
 use Bio::Graphics::Browser2::DataLoader;
@@ -13,6 +13,7 @@ use POSIX ();
 use Carp 'croak';
 
 use constant DEBUG => 0;
+my $HASBIGWIG;
 
 # The intent of this is to provide a single unified interface for managing
 # a user's uploaded and shared tracks.
@@ -173,9 +174,9 @@ sub source_files {
 sub trackname_from_url {
     my $self     = shift;
     my $url      = shift;
-
     my $uniquefy = shift;
-    (my $track_name=$url) =~ tr!a-zA-Z0-9_%^@.!_!cs;
+
+    (my $track_name=$url) =~ tr!a-zA-Z0-9_%^@.-!_!cs;
 
     if (length $track_name > $self->max_filename) {
 	$track_name = substr($track_name,0,$self->max_filename);
@@ -230,7 +231,11 @@ sub import_url {
 
     if ($url =~ /\.bam$/) {
 	print $f $self->remote_bam_conf($track_name,$url,$key);
-    } else {
+    } 
+    elsif ($url =~ /\.bw$/) {
+	print $f $self->remote_bigwig_conf($track_name,$url,$key);
+    }
+    else {
 	print $f $self->remote_mirror_conf($track_name,$url,$key);
     }
     close $f;
@@ -414,6 +419,13 @@ sub get_loader {
 # of the file. The @$lines will contain the lines that were consumed
 # during this operation so that the info isn't lost.
 sub guess_upload_type {
+    my $self = shift;
+    my ($type,$lines,$eol) = $self->_guess_upload_type(@_);
+    $type = 'bigwig' if $type eq 'wiggle' && $self->has_bigwig;
+    return ($type,$lines,$eol);
+}
+
+sub _guess_upload_type {
     my $self = shift;
     my ($filename,$fh) = @_;
 
@@ -474,6 +486,14 @@ sub guess_upload_type {
     return;
 }
 
+sub has_bigwig {
+    my $self = shift;
+    return $HASBIGWIG if defined $HASBIGWIG;
+    return $HASBIGWIG = 1 if Bio::DB::BigWig->can('new');
+    my $result = eval "require Bio::DB::BigWig; 1";
+    return $HASBIGWIG = $result || 0;
+}
+
 sub install_filter {
     my $self = shift;
     my ($in_fh,$command) = @_;
@@ -562,6 +582,34 @@ END
     ;
 }
 
+sub remote_bigwig_conf {
+    my $self = shift;
+    my ($track_name,$url,$key) = @_;
+    my $id = rand(1000);
+    my $dbname = "remotebw_$id";
+    my $track_id = $track_name;
+    warn "remote_bigwig_conf";
+    return <<END;
+[$dbname:database]
+db_adaptor = Bio::DB::BigWig
+db_args    = -bigwig $url
+search options = none
+
+>>>>>>>>>>>>>> cut here <<<<<<<<<<<<
+[$track_id]
+database        = $dbname
+feature         = summary
+glyph           = wiggle_whiskers
+max_color       = lightgrey
+min_color       = lightgrey
+mean_color      = black
+stdev_color     = grey
+stdev_color_neg = grey
+height          = 20
+
+END
+}
+
 package Bio::Graphics::Browser2::UserConf;
 
 use base 'Tie::Handle';
